pub struct SolrSingleServerHost {
pub host: String,
}Expand description
Connect to a single solr host Good for if you have an external load balancer
use solrstice::{AsyncSolrCloudClient, SolrServerContextBuilder, SolrSingleServerHost};
let host = SolrSingleServerHost::new("localhost:8983");
let client = AsyncSolrCloudClient::new(SolrServerContextBuilder::new(host).build());Fields
host: StringImplementations
Sourceimpl SolrSingleServerHost
impl SolrSingleServerHost
Sourcepub fn new<S: Into<String>>(host: S) -> SolrSingleServerHost
pub fn new<S: Into<String>>(host: S) -> SolrSingleServerHost
Connect to a single solr host Good for if you have an external load balancer
use solrstice::{AsyncSolrCloudClient, SolrServerContextBuilder, SolrSingleServerHost};
let host = SolrSingleServerHost::new("localhost:8983");
let client = AsyncSolrCloudClient::new(SolrServerContextBuilder::new(host).build());Trait Implementations
Sourceimpl Clone for SolrSingleServerHost
impl Clone for SolrSingleServerHost
Sourcefn clone(&self) -> SolrSingleServerHost
fn clone(&self) -> SolrSingleServerHost
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for SolrSingleServerHost
impl RefUnwindSafe for SolrSingleServerHost
impl Send for SolrSingleServerHost
impl Sync for SolrSingleServerHost
impl Unpin for SolrSingleServerHost
impl UnwindSafe for SolrSingleServerHost